## stats

A collection of functions used to compute and plot statistics relevant
to Bayesian filters.

### Gaussian

::: bayesian_filters.stats.stats.gaussian

### Multiply Gaussians

::: bayesian_filters.stats.stats.mul

### Add Gaussians

::: bayesian_filters.stats.stats.add

### Log Likelihood

::: bayesian_filters.stats.stats.log_likelihood

### Likelihood

::: bayesian_filters.stats.stats.likelihood

### Log PDF

::: bayesian_filters.stats.stats.logpdf

### Multivariate Gaussian

::: bayesian_filters.stats.stats.multivariate_gaussian

### Multivariate Multiply

::: bayesian_filters.stats.stats.multivariate_multiply

### Plot Gaussian CDF

::: bayesian_filters.stats.stats.plot_gaussian_cdf

### Plot Gaussian PDF

::: bayesian_filters.stats.stats.plot_gaussian_pdf

### Plot Discrete CDF

::: bayesian_filters.stats.stats.plot_discrete_cdf

### Plot Gaussian

::: bayesian_filters.stats.stats.plot_gaussian

### Covariance Ellipse

::: bayesian_filters.stats.stats.covariance_ellipse

### Plot Covariance Ellipse

::: bayesian_filters.stats.stats.plot_covariance_ellipse

### Normal CDF

::: bayesian_filters.stats.stats.norm_cdf

### Random Student-t

::: bayesian_filters.stats.stats.rand_student_t

### NEES

::: bayesian_filters.stats.stats.NEES

### Mahalanobis Distance

::: bayesian_filters.stats.stats.mahalanobis
